using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
// Insert the API namespace. You must have added a reference to the CZEMApi ActiveX control in Visual Studio before, as described in the SmartSEM Remote API Manual.
// Set the APILib properties 'Embed Interop types" to False and 'Local copy' to True. 
using APILib;
// Needed for using the VariantWrapper class
using System.Runtime.InteropServices;


namespace _10_Grab
{
    public partial class Form1 : Form
    {
        // Create a new Api object
        Api CZEMApi = new Api();

        // Define a flag to check for initialisation later
        private bool apiInitialised = false;

        public Form1()
        {
            InitializeComponent();
        }

        // Code executed when buttonInitialiseCZEMApi is clicked
        private void buttonInitialiseCZEMApi_Click(object sender, System.EventArgs e)
        {
            //Initalise communication between the CZEMApi OCX and EM Server
            long lReturn = CZEMApi.Initialise("");
            //long lReturn = CZEMApi.InitialiseRemoting("");

            if (lReturn == 0)
            {
                apiInitialised = true;
                MessageBox.Show("Remote API correctly initialised.");
            }
            else
            {
                MessageBox.Show("Remote API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        // Code executed when buttonGrab is clicked
        private void buttonGrab_Click(object sender, System.EventArgs e)
        {
            if (apiInitialised)
            {
                short ix = 0;
                short iy = 0;
                short il = 1024;
                short ih = 768;
                short ir = -1;
                //string filename = "C:\\Capture.tiff";
                string filename = "U:\\My Documents\\SmartSEM_API\\Capture.tiff";

                // Set image user text
                string value = "Blubber";
                // Initialise a VariantWrapper object to reference the parameter value
                object vValue = new VariantWrapper(value);
                //CZEMApi.Set("SV_USER_TEXT", ref vValue);
                CZEMApi.Set("SV_SAMPLE_ID", ref vValue);

                // Get the stage position values
                long lReply = CZEMApi.Grab(ix, iy, il, ih, ir, filename);

                // Show success message, or an error message in case of an error
                switch ((ZeissErrorCode)lReply)
                {
                    case ZeissErrorCode.API_E_NO_ERROR:
                        MessageBox.Show("Image grabbed and saved.");
                        break;

                    case ZeissErrorCode.API_E_GRAB_FAIL:
                        MessageBox.Show("Grab command failed.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_NOT_INITIALISED:
                        MessageBox.Show("API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;
                }
            }
        }

        // Some API error codes, using an enum type
        public enum ZeissErrorCode
        {
            API_E_NO_ERROR = 0,

            // Grab command failed
            API_E_GRAB_FAIL = 1016,

            // API not initialised
            API_E_NOT_INITIALISED = 1019
        }


    }
}