﻿using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
// Insert the API namespace. You must have added a reference to the CZEMApi ActiveX control in Visual Studio before, as described in the SmartSEM Remote API Manual.
// Set the APILib properties 'Embed Interop types" to False and 'Local copy' to True. 
using APILib;


namespace _13_Notify
{
    public partial class Form1 : Form
    {
        // Create a new Api object
        Api CZEMApi = new Api();
      
        // Define a flag to check for initialisation later
        private bool apiInitialised = false;

        public Form1()
        {
            InitializeComponent();

            //Calling  event notification for parameter changes
            CZEMApi.Notify += new _EMApiEvents_NotifyEventHandler(CZEMApi_Notify);
        }

        // Code executed when buttonInitialiseCZEMApi is clicked
        private void buttonInitialiseCZEMApi_Click(object sender, System.EventArgs e)
        {
            // Initalise communication between the CZEMApi OCX and EM Server
            long lReturn = CZEMApi.Initialise("");
            // long lReturn = CZEMApi.InitialiseRemoting("");

            if (lReturn == 0)
            {
                apiInitialised = true;
                MessageBox.Show("Remote API correctly initialised.");
            }
            else
            {
                MessageBox.Show("Remote API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        // Code executed when buttonSetNotify is clicked
        private void buttonSetNotify_Click(object sender, System.EventArgs e)
        {
            if (apiInitialised)
            {
                // Enable parameter notification 
                long lReply = CZEMApi.SetNotify("AP_MAG", 1);

                // Show the value, or an error message in case of an error
                switch ((ZeissErrorCode)lReply)
                {
                    case ZeissErrorCode.API_E_NO_ERROR:
                        break;

                    case ZeissErrorCode.API_E_NOTIFY_TRANSLATE_FAIL:
                        MessageBox.Show("Failed to translate parameter to an id.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_NOTIFY_SET_FAIL:
                        MessageBox.Show("Set notification failed.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_NOT_INITIALISED:
                        MessageBox.Show("API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;
                }
            }
        }

        private void CZEMApi_Notify(string lpszParameter, int reason)
        {
            switch (lpszParameter)
            {
                case "AP_MAG":
                    if (reason == 0) MessageBox.Show("Parameter AP_MAG modified.");
                    break;
            }
        }

        // Some API error codes, using an enum type
        public enum ZeissErrorCode
        {
            API_E_NO_ERROR = 0,

            // API not initialised
            API_E_NOT_INITIALISED = 1019,

            // Failed to translate parameter to an id
            API_E_NOTIFY_TRANSLATE_FAIL = 1020,

            // Set notification failed
            API_E_NOTIFY_SET_FAIL = 1021
        }


    }
}