﻿using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
// Insert the API namespace. You must have added a reference to the CZEMApi ActiveX control in Visual Studio before, as described in the SmartSEM Remote API Manual.
// Set the APILib properties 'Embed Interop types" to False and 'Local copy' to True. 
using APILib;
// Needed for using the VariantWrapper class
using System.Runtime.InteropServices;


namespace _4_GetLimits
{
    public partial class Form1 : Form
    {
        // Create a new Api object
        Api CZEMApi = new Api();

        // Define a flag to check for initialisation later
        private bool apiInitialised = false;

        // Some API error codes
        const int API_E_NO_ERROR = 0;

        // Failed to translate parameter into an id
        const int API_E_GET_TRANSLATE_FAIL = 1000;

        // API not initialised
        const int API_E_NOT_INITIALISED = 1019;

        // Get limits failed
        const int API_E_GET_LIMITS_FAIL = 1022;

        public Form1()
        {
            InitializeComponent();
        }

        // Code executed when buttonInitialiseCZEMApi is clicked
        private void buttonInitialiseCZEMApi_Click(object sender, System.EventArgs e)
        {
            // Initalise communication between the CZEMApi OCX and EM Server
            long lReturn = CZEMApi.Initialise("");
            // long lReturn = CZEMApi.InitialiseRemoting("");

            if (lReturn == 0)
            {
                apiInitialised = true;
                MessageBox.Show("Remote API correctly initialised.");
            }
            else
            {
                MessageBox.Show("Remote API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        // Code executed when buttonGetMagLimits is clicked
        private void buttonGetMagLimits_Click(object sender, System.EventArgs e)
        {
            if (apiInitialised)
            {   
                // Initialise two VariantWrapper objects to reference the parameter values
                object vMinValue = new VariantWrapper((float)0.0f);
                object vMaxValue = new VariantWrapper((float)0.0f);

                // Get parameter limits numeric values 
                long lReply = CZEMApi.GetLimits("AP_MAG", ref vMinValue, ref vMaxValue);

                // Show the values, or an error message in case of an error
                switch (lReply)
                {
                    case API_E_NO_ERROR:
                        MessageBox.Show("min. Mag = " + vMinValue.ToString() + ", max. Mag = " + vMaxValue.ToString());
                        break;

                    case API_E_GET_TRANSLATE_FAIL:
                        MessageBox.Show("Failed to translate parameter into an id.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case API_E_NOT_INITIALISED:
                        MessageBox.Show("API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case API_E_GET_LIMITS_FAIL:
                        MessageBox.Show("Get limits failed.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;
                }
            }
        }

    }
}