﻿using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
// Insert the API namespace. You must have added a reference to the CZEMApi ActiveX control in Visual Studio before, as described in the SmartSEM Remote API Manual.
// Set the APILib properties 'Embed Interop types" to False and 'Local copy' to True. 
using APILib;
// Needed for using the VariantWrapper class
using System.Runtime.InteropServices;


namespace _5_Get
{
    public partial class Form1 : Form
    {
        // Create a new Api object
        Api CZEMApi = new Api();

        // Define a flag to check for initialisation later
        private bool apiInitialised = false;

        public Form1()
        {
            InitializeComponent();
        }

        // Code executed when buttonInitialiseCZEMApi is clicked
        private void buttonInitialiseCZEMApi_Click(object sender, System.EventArgs e)
        {
            // Initalise communication between the CZEMApi OCX and EM Server
            long lReturn = CZEMApi.Initialise("");
            // long lReturn = CZEMApi.InitialiseRemoting("");

            if (lReturn == 0)
            {
                apiInitialised = true;
                MessageBox.Show("Remote API correctly initialised.");
            }
            else
            {
                MessageBox.Show("Remote API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        // Code executed when buttonGetMagLimits is clicked
        private void buttonGetMag_Click(object sender, System.EventArgs e)
        {
            if (apiInitialised)
            {
                // Initialise a VariantWrapper object to reference the parameter value
               // object vValue = new VariantWrapper((float)0.0f);
                object vValue = new VariantWrapper("");

                // Get parameter numeric value 
                long lReply = CZEMApi.Get("AP_MAG", ref vValue);
                //long lReply = CZEMApi.Get("SV_USER_NAME", ref vValue);

                // Show the value, or an error message in case of an error
                switch ((ZeissErrorCode)lReply)
                {
                    case ZeissErrorCode.API_E_NO_ERROR:
                        MessageBox.Show("Mag = " + vValue.ToString());
                        break;

                    case ZeissErrorCode.API_E_GET_TRANSLATE_FAIL:
                        MessageBox.Show("Failed to translate parameter into an id.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_GET_AP_FAIL:
                        MessageBox.Show("Failed to get analogue value.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_GET_DP_FAIL:
                        MessageBox.Show("Failed to get digital value.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_GET_BAD_PARAMETER:
                        MessageBox.Show("Parameter supplied is not analogue nor digital.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_NOT_INITIALISED:
                        MessageBox.Show("API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;
                }
            }
        }

        // Some API error codes
        // This time we use an enum type
        public enum ZeissErrorCode
        {
            API_E_NO_ERROR = 0,

            // Failed to translate parameter into an id
            API_E_GET_TRANSLATE_FAIL = 1000,

            // Failed to get analogue value
            API_E_GET_AP_FAIL = 1001,

            // Failed to get digital value
            API_E_GET_DP_FAIL = 1002,

            // Parameter supplied is not analogue nor digital
            API_E_GET_BAD_PARAMETER = 1003,

            // API not initialised
            API_E_NOT_INITIALISED = 1019
        }


    }
}