using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
// Insert the API namespace. You must have added a reference to the CZEMApi ActiveX control in Visual Studio before, as described in the SmartSEM Remote API Manual.
// Set the APILib properties 'Embed Interop types" to False and 'Local copy' to True. 
using APILib;
// Needed for using the VariantWrapper class
using System.Runtime.InteropServices;


namespace _6_Set
{
    public partial class Form1 : Form
    {
        // Create a new Api object
        Api CZEMApi = new Api();

        // Define a flag to check for initialisation later
        private bool apiInitialised = false;

        public Form1()
        {
            InitializeComponent();
        }

        // Code executed when buttonInitialiseCZEMApi is clicked
        private void buttonInitialiseCZEMApi_Click(object sender, System.EventArgs e)
        {
            //Initalise communication between the CZEMApi OCX and EM Server
            long lReturn = CZEMApi.Initialise("");
            //long lReturn = CZEMApi.InitialiseRemoting("");

            if (lReturn == 0)
            {
                apiInitialised = true;
                MessageBox.Show("Remote API correctly initialised.");
            }
            else
            {
                MessageBox.Show("Remote API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        // Code executed when buttonSetMagLimits is clicked
        private void buttonSetMag_Click(object sender, System.EventArgs e)
        {
            if (apiInitialised)
            {
                string value = textBoxEnterMag.Text;
                // Initialise a VariantWrapper object to reference the parameter value
                object vValue = new VariantWrapper(value);

                // Set parameter value
                long lReply = CZEMApi.Set("AP_MAG", ref vValue);
                
                // Show the value, or an error message in case of an error
                // Set() returns error 1007 (API_E_SET_FLOAT_LIMIT_LOW) if the value string does not contain a number
                switch ((ZeissErrorCode)lReply)
                {
                    case ZeissErrorCode.API_E_NO_ERROR:
                        MessageBox.Show("Mag set to = " + value);
                        break;

                    case ZeissErrorCode.API_E_SET_TRANSLATE_FAIL:
                        MessageBox.Show("Failed to translate parameter into an id.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_SET_STATE_FAIL:
                        MessageBox.Show("Failed to set a digital state.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_SET_FLOAT_FAIL:
                        MessageBox.Show("Failed to set a float value.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_SET_FLOAT_LIMIT_LOW:
                        MessageBox.Show("Value supplied is too low.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_SET_FLOAT_LIMIT_HIGH:
                        MessageBox.Show("Value supplied is too high.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_SET_BAD_VALUE:
                        MessageBox.Show("Value supplied is is of wrong type.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_NOT_INITIALISED:
                        MessageBox.Show("API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;
                }
            }
        }

        // Some API error codes, using an enum type
        public enum ZeissErrorCode
        {
            API_E_NO_ERROR = 0,

            // Failed to translate parameter into an id
            API_E_SET_TRANSLATE_FAIL = 1004,

            // Failed to set a digital state 
            API_E_SET_STATE_FAIL = 1005,

            // Failed to set a float value
            API_E_SET_FLOAT_FAIL = 1006,

            // Value supplied is too low
            API_E_SET_FLOAT_LIMIT_LOW = 1007,

            // Value supplied is too high
            API_E_SET_FLOAT_LIMIT_HIGH = 1008,

            // Value supplied is is of wrong type
            API_E_SET_BAD_VALUE = 1009,

            // API not initialised
            API_E_NOT_INITIALISED = 1019
        }


    }
}