using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
// Insert the API namespace. You must have added a reference to the CZEMApi ActiveX control in Visual Studio before, as described in the SmartSEM Remote API Manual.
// Set the APILib properties 'Embed Interop types" to False and 'Local copy' to True. 
using APILib;


namespace _7_Execute
{
    public partial class Form1 : Form
    {
        // Create a new Api object
        Api CZEMApi = new Api();

        // Define a flag to check for initialisation later
        private bool apiInitialised = false;

        public Form1()
        {
            InitializeComponent();
        }

        // Code executed when buttonInitialiseCZEMApi is clicked
        private void buttonInitialiseCZEMApi_Click(object sender, System.EventArgs e)
        {
            //Initalise communication between the CZEMApi OCX and EM Server
            long lReturn = CZEMApi.Initialise("");
            //long lReturn = CZEMApi.InitialiseRemoting("");

            if (lReturn == 0)
            {
                apiInitialised = true;
                MessageBox.Show("Remote API correctly initialised.");
            }
            else
            {
                MessageBox.Show("Remote API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        // Code executed when buttonExecute is clicked
        private void buttonExecute_Click(object sender, System.EventArgs e)
        {
            if (apiInitialised)
            {
                // Execute the specified command
                long lReply = CZEMApi.Execute("CMD_BEAM_ON");

                // Show success message, or an error message in case of an error
                switch ((ZeissErrorCode)lReply)
                {
                    case ZeissErrorCode.API_E_NO_ERROR:
                        MessageBox.Show("Command executed.");
                        break;

                    case ZeissErrorCode.API_E_EXEC_TRANSLATE_FAIL:
                        MessageBox.Show("Failed to translate command into an id.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_EXEC_CMD_FAIL:
                        MessageBox.Show("Failed to execute command.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_EXEC_MCF_FAIL:
                        MessageBox.Show("Failed to execute file macro.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_EXEC_MCL_FAIL:
                        MessageBox.Show("Failed to execute library macro.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_EXEC_BAD_COMMAND:
                        MessageBox.Show("Command supplied is not implemented.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_NOT_INITIALISED:
                        MessageBox.Show("API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;
                }
            }
        }

        // Some API error codes, using an enum type
        public enum ZeissErrorCode
        {
            API_E_NO_ERROR = 0,

            // Failed to translate command into an id
            API_E_EXEC_TRANSLATE_FAIL = 1011,

            // Failed to execute command
            API_E_EXEC_CMD_FAIL = 1012,

            // Failed to execute file macro
            API_E_EXEC_MCF_FAIL = 1013,

            // Failed to execute library macro
            API_E_EXEC_MCL_FAIL = 1014,

            // Command supplied is not implemented
            API_E_EXEC_BAD_COMMAND = 1015,

            // API not initialised
            API_E_NOT_INITIALISED = 1019
        }


    }
}