using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
// Insert the API namespace. You must have added a reference to the CZEMApi ActiveX control in Visual Studio before, as described in the SmartSEM Remote API Manual.
// Set the APILib properties 'Embed Interop types" to False and 'Local copy' to True. 
using APILib;
// Needed for using the VariantWrapper class
using System.Runtime.InteropServices;


namespace _8_GetStagePosition
{
    public partial class Form1 : Form
    {
        // Create a new Api object
        Api CZEMApi = new Api();

        // Define a flag to check for initialisation later
        private bool apiInitialised = false;

        public Form1()
        {
            InitializeComponent();
        }

        // Code executed when buttonInitialiseCZEMApi is clicked
        private void buttonInitialiseCZEMApi_Click(object sender, System.EventArgs e)
        {
            //Initalise communication between the CZEMApi OCX and EM Server
            long lReturn = CZEMApi.Initialise("");
            //long lReturn = CZEMApi.InitialiseRemoting("");

            if (lReturn == 0)
            {
                apiInitialised = true;
                MessageBox.Show("Remote API correctly initialised.");
            }
            else
            {
                MessageBox.Show("Remote API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        // Code executed when buttonGetStagePosition is clicked
        private void buttonGetStagePosition_Click(object sender, System.EventArgs e)
        {
            if (apiInitialised)
            {
                object vXValue = new VariantWrapper((float)0.0f);
                object vYValue = new VariantWrapper((float)0.0f);
                object vZValue = new VariantWrapper((float)0.0f);
                object vTValue = new VariantWrapper((float)0.0f);
                object vRValue = new VariantWrapper((float)0.0f);
                object vMValue = new VariantWrapper((float)0.0f);

                // Get the stage position values
                long lReply = CZEMApi.GetStagePosition(ref vXValue, ref vYValue, ref vZValue, ref vTValue, ref vRValue, ref vMValue);

                //Show the values, or an error message in case of an error
                switch ((ZeissErrorCode)lReply)
                {
                    case ZeissErrorCode.API_E_NO_ERROR:
                        MessageBox.Show("Stage position is: " + vXValue + "; " + vYValue  + "; " + vZValue + "; " + vTValue + "; " + vRValue + "; " + vMValue + ".");
                        break;

                    case ZeissErrorCode.API_E_GET_STAGE_FAIL:
                        MessageBox.Show("Get Stage position failed.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_NOT_INITIALISED:
                        MessageBox.Show("API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;
                }
            }
        }

        // Some API error codes, using an enum type
        public enum ZeissErrorCode
        {
            API_E_NO_ERROR = 0,

            // Get Stage position failed
            API_E_GET_STAGE_FAIL = 1017,

            // API not initialised
            API_E_NOT_INITIALISED = 1019
        }


    }
}