using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
// Insert the API namespace. You must have added a reference to the CZEMApi ActiveX control in Visual Studio before, as described in the SmartSEM Remote API Manual.
// Set the APILib properties 'Embed Interop types" to False and 'Local copy' to True. 
using APILib;


namespace _9_MoveStage
{
    public partial class Form1 : Form
    {
        // Create a new Api object
        Api CZEMApi = new Api();

        // Define a flag to check for initialisation later
        private bool apiInitialised = false;

        public Form1()
        {
            InitializeComponent();
        }

        // Code executed when buttonInitialiseCZEMApi is clicked
        private void buttonInitialiseCZEMApi_Click(object sender, System.EventArgs e)
        {
            //Initalise communication between the CZEMApi OCX and EM Server
            long lReturn = CZEMApi.Initialise("");
            //long lReturn = CZEMApi.InitialiseRemoting("");

            if (lReturn == 0)
            {
                apiInitialised = true;
                MessageBox.Show("Remote API correctly initialised.");
            }
            else
            {
                MessageBox.Show("Remote API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        // Code executed when buttonMoveStage is clicked
        private void buttonMoveStage_Click(object sender, System.EventArgs e)
        {
            if (apiInitialised)
            {
                float sXValue = 0.06F;
                float sYValue = 0.06F;
                float sZValue = 0.004F;
                float sTValue = 1;
                float sRValue = 10;
                float sMValue = 0;

                // Set the stage position values
                long lReply = CZEMApi.MoveStage(sXValue, sYValue, sZValue, sTValue, sRValue, sMValue);

                // Show the values, or an error message in case of an error
                switch ((ZeissErrorCode)lReply)
                {
                    case ZeissErrorCode.API_E_NO_ERROR:
                        MessageBox.Show("Stage moved to: " + sXValue + "; " + sYValue  + "; " + sZValue + "; " + sTValue + "; " + sRValue + "; " + sMValue + ".");
                        break;

                    case ZeissErrorCode.API_E_MOVE_STAGE_FAIL:
                        MessageBox.Show("Move Stage position failed.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;

                    case ZeissErrorCode.API_E_NOT_INITIALISED:
                        MessageBox.Show("API not initialised.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        break;
                }
            }
        }

        // Some API error codes, using an enum type
        public enum ZeissErrorCode
        {
            API_E_NO_ERROR = 0,

            // Move Stage position failed
            API_E_MOVE_STAGE_FAIL = 1018,

            // API not initialised
            API_E_NOT_INITIALISED = 1019
        }


    }
}